## dbt-bigquery 1.11.0-b2 - November 04, 2025

### Fixes

- Fix BigFrames python model + oauth + notebook template by adding a Request to creds.refresh calll ([#1379](https://github.com/dbt-labs/dbt-adapters/issues/1379))

### Under the Hood

- Update bigquery job handling to invoke job.cancel on timeout ([#1355](https://github.com/dbt-labs/dbt-adapters/issues/1355))
- Test that bigquery does nothing with volatility ([#1345](https://github.com/dbt-labs/dbt-adapters/issues/1345))
- Test handling of unknown function macro lookup ([#1344](https://github.com/dbt-labs/dbt-adapters/issues/1344))

### Dependencies

- Drop support for python 3.9 ([#1412](https://github.com/dbt-labs/dbt-adapters/pull/1412))
